@@ -96,7 +96,7 @@ installDebianPackageAndRecommends ()
     #
     # Install the packages
     #
-    DEBIAN_FRONTEND=noninteractive chroot ${prefix} /usr/bin/apt-get --yes --force-yes install "$@"
+    DEBIAN_FRONTEND=noninteractive chroot ${prefix} /usr/bin/apt-get --yes install "$@"
 
     #
     #  Remove the policy-rc.d script.
@@ -123,7 +123,7 @@ installDebianPackage ()
     prefix=$1
     shift
 
-    installDebianPackageAndRecommends ${prefix} --no-install-recommends "$@"
+    installDebianPackageAndRecommends ${prefix} -o APT::Install-Recommends=false "$@"
 }
 
 #
@@ -322,7 +322,7 @@ removeDebianPackage ()
     #
     # Log our options
     #
-    logMessage "Purging Debian package ${package} from prefix ${prefix}"
+    logMessage "Purging Debian package $@ from prefix ${prefix}"
 
     #
     #  We require a prefix
